@@ -3,7 +3,7 @@ package Image::Xbm ;    # Documented at the __END__
 use strict ;
 
 use vars qw( $VERSION @ISA ) ;
-$VERSION = '1.09' ;
+$VERSION = '1.10' ;
 
 use Image::Base ;
 
@@ -390,7 +390,7 @@ sub load { # Object method
         $height = $1, next if /#define.*height\s+(\d+)/o ; 
         $hotx   = $1, next if /#define.*_x_hot\s+(\d+)/o ; 
         $hoty   = $1, next if /#define.*_y_hot\s+(\d+)/o ; 
-        push @val, map { hex } /0[xX]([A-Fa-f\d][A-Fa-f\d]?)/g ; 
+        push @val, map { hex } /0[xX]([A-Fa-f\d][A-Fa-f\d]?)\b/g ; 
     }
     croak "load() failed to find dimension(s) in `$file'" 
     unless defined $width and defined $height ;
@@ -446,7 +446,7 @@ sub save { # Object method
 
     $file =~ s,^.*/,,o ;            
     $file =~ s/\.xbm$//o ;         
-    $file =~ tr/[-_A-Za-z0-9]/_/c ;
+    $file =~ tr/_A-Za-z0-9/_/c ;
     
     print $fh "#define ${file}_width $width\n#define ${file}_height $height\n" ;
     print $fh "#define ${file}_x_hot $hotx\n#define ${file}_y_hot $hoty\n" 
@@ -771,6 +771,13 @@ Returns the image as a string of 0's and 1's, e.g.
 
 =head1 CHANGES
 
+2016/02/23 (Slaven Rezic)
+
+Make sure macro/variable names are always sane.
+
+More strict parsing of bits.
+
+
 2000/11/09
 
 Added Jerrad Pierce's patch to allow load() to accept filehandles or strings;
